import cdk = require('@aws-cdk/cdk');
/**
 * Properties for a SecretString
 */
export interface SecretStringProps {
    /**
     * Unique identifier or ARN of the secret
     */
    readonly secretId: string;
    /**
     * Specifies the secret version that you want to retrieve by the staging label attached to the version.
     *
     * Can specify at most one of versionId and versionStage.
     *
     * @default AWSCURRENT
     */
    readonly versionStage?: string;
    /**
     * Specifies the unique identifier of the version of the secret that you want to use in stack operations.
     *
     * Can specify at most one of versionId and versionStage.
     *
     * @default AWSCURRENT
     */
    readonly versionId?: string;
}
/**
 * References a secret string in Secrets Manager
 *
 * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-secretsmanager-secret.html
 */
export declare class SecretString extends cdk.DynamicReference {
    private readonly props;
    constructor(scope: cdk.Construct, id: string, props: SecretStringProps);
    /**
     * Return the full value of the secret
     */
    readonly stringValue: string;
    /**
     * Interpret the secret as a JSON object and return a field's value from it
     */
    jsonFieldValue(key: string): string;
    private resolveStringForJsonKey;
}
